
# convert to queryset

This package enables you to convert list,tuple and set into queryset

To install this package, use 

```bash
pip install convert-to-queryset
```
# for list 
import it using the following
```bash
from convert_to_queryset import list_to_queryset
```

it will take two arguments: model and list
```bash
list_to_queryset(model,list)
```